/*
 * Copyright (c) 2005,2006 Ryo Ichinose
 *
 * This file is part of Space Maze.
 * 
 * Space Maze is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; version 2 of the License.
 * 
 * Space Maze is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with Space Maze; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
 */

/*!
 * @file
 * @brief Handles enemy entity data and draws it onto the scren.
 *
 * "$Id: enemy.c,v 1.1.1.1 2006/07/22 18:07:56 ryo Exp $"
 */

#include <math.h>
#include <stdio.h>
#include <string.h>

#include "RLgt.h"
#include "enemy.h"
#include "entity.h"


/*!
 * Initializes enemy data structures.
 *
 * @param enemy  [i/o] An enemy data storage.
 * @param app    [in]  GUI toolkit context.
 * @param sound  [in]  Sound library context.
 * @param type   [in]  Type of an enemy.
 * @param screen [in]  Screen definition on which enemies should be drawn.
 */
void
enemy_init( Entity* enemy, RLgtApp* app, RLsoundContext* sound, EnemyType type, RLrect* screen )
{
	if ( enemy == NULL || app == NULL || screen == NULL ) {
		return;
	}

	entity_init( enemy, app, sound, screen );

	switch ( type ) {
		case ENEMY_MISSILER:
			missiler_init( enemy );
			break;

		case ENEMY_SCULL:
			scull_init( enemy );
			break;

		case ENEMY_FORTRESS:
			fortress_init( enemy );
			break;

		case ENEMY_FLYER:
			flyer_init( enemy );
			break;

		case ENEMY_BALL:
		default:
			ball_init( enemy );
	}
}


/* End of enemy.c */
