/*
 * Copyright (c) 2005-2007 Ryo Ichinose
 *
 * This file is part of Space Maze.
 * 
 * Space Maze is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; version 2 of the License.
 * 
 * Space Maze is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with Space Maze; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
 */

/*!
 * @file
 * @brief Handles item entity data and draws it onto the screen.
 *
 * "$Id: item.c,v 1.2 2007/11/04 11:41:23 ryo Exp $"
 */

#include <stdio.h>
#include <string.h>

#include "item.h"
#include "entity.h"


/*!
 * Initializes item data structures.
 *
 * @param item        [i/o] An item data storage.
 * @param app         [in]  GUI toolkit context.
 * @param type        [in]  Type of an item.
 * @param screen      [in]  Screen definition on which an item should be drawn.
 * @param image_index [in]  Image indexes to refer to the real data stored in GUI toolkit context.
 */
void
item_init( Entity* item, RLgtApp* app, ItemType type, RLrect* screen, int image_index )
{
	if ( item == NULL || app == NULL || screen == NULL ) {
		return;
	}

	entity_init( item, app, NULL, screen );
	item->drawing_image = image_index;

	switch ( type ) {
		case ITEM_KEY:
		default:
			key_init( item );
	}
}


/*!
 * Sets item status to exploding.
 */
void
item_explode( Entity* item )
{
	if ( item == NULL ) {
		return;
	}

	/*
	 * Currently, I want to make an item disappear right after 
	 * it is set to explode. 
	 * No effect is going to be implemented for a while ...
	 */
	item->is_alive     = 0;
	item->is_exploding = 0;
}


/* End of item.c */
