/*
 * Copyright (c) 2005,2006 Ryo Ichinose
 *
 * This file is part of Space Maze.
 * 
 * Space Maze is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; version 2 of the License.
 * 
 * Space Maze is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with Space Maze; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
 */

/*!
 * @file
 * @brief Handles item (key) data and draws it onto the screen.
 *
 * "$Id: key.c,v 1.1.1.1 2006/07/22 18:07:56 ryo Exp $"
 */

#include <stdio.h>

#include "RLgt.h"
#include "RLrect.h"
#include "item.h"
#include "entity.h"


#define KEY_WIDTH  40
#define KEY_HEIGHT 40


/*!
 * Initializes an item (key) specific data.
 * No null check is executed because this is a back-end of item_init().
 */
void
key_init( Entity* key )
{
	key->width         = KEY_WIDTH;
	key->height        = KEY_HEIGHT;
	key->draw_func     = key_draw;
}


/*!
 * Draws an item (key) onto the screen.
 * No null check is executed because this is a back-end of entity_draw().
 */
void
key_draw( Entity* key )
{
	if ( entity_is_alive( key ) ) {
		RLrect rect;
		int screen_x;
		int screen_y;

		SCREEN_POSITION( key, screen_x, screen_y );

		rect.lefttop_x = screen_x - key->width  / 2;
		rect.lefttop_y = screen_y - key->height / 2;
		rect.width     = key->width;
		rect.height    = key->height;

		if ( rlib_rect_overlap( &rect, &( key->screen ) ) ) {
			RL_GT_DRAW_IMAGE(
				key->gt_app,
				key->drawing_image,
				screen_x,
				screen_y
				);
		}
	}
}


/* End of key.c */
