/*
 * Copyright (c) 2005,2006 Ryo Ichinose
 *
 * This file is part of Space Maze.
 * 
 * Space Maze is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; version 2 of the License.
 * 
 * Space Maze is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with Space Maze; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
 */

/*!
 * @file
 * @brief Handles missile (cannon) data and draws it onto the screen.
 *
 * "$Id: cannon.c,v 1.1.1.1 2006/07/22 18:07:56 ryo Exp $"
 */

#include <math.h>
#include <stdio.h>

#include "RLgt.h"
#include "RLrect.h"
#include "missile.h"
#include "entity.h"


#define CANNON_WIDTH    5
#define CANNON_HEIGHT   5
#define CANNON_STRENGTH 10 
#define CANNON_VELOCITY 2.5


/*!
 * Initializes a missile (cannon) specific data.
 * No null check is executed because this is a back-end of missile_init().
 */
void
cannon_init( Entity* cannon )
{
	cannon->width        = CANNON_WIDTH;
	cannon->height       = CANNON_HEIGHT;
	cannon->strength     = CANNON_STRENGTH;
	cannon->vmax         = ( CANNON_VELOCITY / entity_get_fps_ratio() );
	cannon->draw_func    = cannon_draw;
}


/*!
 * Draws a missile (cannon) onto the screen.
 * No null check is executed because this is a back-end of entity_draw().
 */
void
cannon_draw( Entity* cannon )
{
	if ( entity_is_alive( cannon ) ) {
		int screen_x;
		int screen_y;

		SCREEN_POSITION( cannon, screen_x, screen_y );

		if ( ! rlib_rect_within( &( cannon->screen ), screen_x, screen_y ) ) {
			return;
		}
			     
		rlib_gt_set_foreground_color( 
			cannon->gt_app,
			RL_GT_MAX_RGB * 0.5, 
			RL_GT_MAX_RGB * 0.7, 
			RL_GT_MAX_RGB * 0.8 
			);

		rlib_gt_fill_arc(
			cannon->gt_app,
			screen_x - cannon->width  / 2,
			screen_y - cannon->height / 2,
			cannon->width,
			cannon->height,
			0,
			360 * 64
			);
	}
}


/* End of cannon.c */
