/*
 * Copyright (c) 2005,2006 Ryo Ichinose
 *
 * This file is part of Space Maze.
 * 
 * Space Maze is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; version 2 of the License.
 * 
 * Space Maze is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with Space Maze; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
 */

/*!
 * @file
 * @brief Handles missile (doughnut) data and draws it onto the screen.
 *
 * "$Id: doughnut.c,v 1.1.1.1 2006/07/22 18:07:56 ryo Exp $"
 */

#include <math.h>
#include <stdio.h>

#include "RLgt.h"
#include "RLrect.h"
#include "missile.h"
#include "entity.h"


#define DOUGHNUT_WIDTH    40
#define DOUGHNUT_HEIGHT   40
#define DOUGHNUT_STRENGTH 20 
#define DOUGHNUT_VELOCITY 7.5


/*!
 * Initializes a missile (doughnut) specific data.
 * No null check is executed because this is a back-end of missile_init().
 */
void
doughnut_init( Entity* doughnut )
{
	doughnut->width         = DOUGHNUT_WIDTH;
	doughnut->height        = DOUGHNUT_HEIGHT;
	doughnut->strength      = DOUGHNUT_STRENGTH;
	doughnut->vmax          = ( DOUGHNUT_VELOCITY / entity_get_fps_ratio() );
	doughnut->draw_func     = doughnut_draw;
}


/*!
 * Draws a missile (doughnut) onto the game screen.
 * No null check is executed because this is a back-end of entity_draw().
 */
void
doughnut_draw( Entity* doughnut )
{
	if ( entity_is_alive( doughnut ) ) {
		int screen_x;
		int screen_y;
		RLrect rect;

		SCREEN_POSITION( doughnut, screen_x, screen_y );

		rlib_rect_init( &rect, 
			     screen_x - doughnut->width  / 2, 
			     screen_y - doughnut->height / 2, 
			     doughnut->width, 
			     doughnut->height );

		if ( ! rlib_rect_overlap( &( doughnut->screen ), &rect ) ) {
			return;
		}

		rlib_gt_set_foreground_color( 
			doughnut->gt_app,
			RL_GT_MAX_RGB,
			RL_GT_MAX_RGB * 0.8,
			RL_GT_MAX_RGB * 0.3
			);

		rlib_gt_fill_arc(
			doughnut->gt_app,
			screen_x - doughnut->width  / 2,
			screen_y - doughnut->height / 2,
			doughnut->width,
			doughnut->height,
			0,
			360 * 64
			);

		rlib_gt_set_foreground_color( doughnut->gt_app, 0, 0, 0 );

		rlib_gt_fill_arc(
			doughnut->gt_app,
			screen_x - doughnut->width  / 4,
			screen_y - doughnut->height / 4,
			doughnut->width  / 2,
			doughnut->height / 2,
			0,
			360 * 64
			);
	}
}


/* End of doughnut.c */
