/*
 * Copyright (c) 2005,2006 Ryo Ichinose
 *
 * This file is part of Space Maze.
 * 
 * Space Maze is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; version 2 of the License.
 * 
 * Space Maze is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with Space Maze; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
 */

/*!
 * @file
 * @brief Handles missile (laser) and draws it onto the screen.
 *
 * "$Id: laser.c,v 1.1.1.1 2006/07/22 18:07:56 ryo Exp $"
 */

#include <math.h>
#include <stdio.h>

#include "RLgt.h"
#include "RLrect.h"
#include "missile.h"
#include "entity.h"


#define LASER_WIDTH    10
#define LASER_HEIGHT   10
#define LASER_STRENGTH 10 
#define LASER_VELOCITY 8.0


/*!
 * Initializes a missile (laser) specific data.
 * No null check is executed because this is a back-end of missile_init().
 */
void
laser_init( Entity* laser )
{
	laser->width              = LASER_WIDTH;
	laser->height             = LASER_HEIGHT;
	laser->strength           = LASER_STRENGTH;
	laser->vmax               = ( LASER_VELOCITY / entity_get_fps_ratio() );
	laser->draw_func          = laser_draw;
}


/*!
 * Draws a missile (laser) onto the screen.
 * No null check is executed because this is a back-end of missile_draw().
 */
void
laser_draw( Entity* laser )
{
#define LASER_POINTS_NUM 5

	if ( entity_is_alive( laser ) ) {
		const double points[ LASER_POINTS_NUM ][2] = {
			{  10.0,    2.5 },
			{  10.0,  - 2.5 },
			{ -10.0,  - 2.5 },
			{ -10.0,    2.5 },
			{  10.0,    2.5 }
		};

		Point converted[ LASER_POINTS_NUM ];
		int screen_x;
		int screen_y;
		int culling = 1;
		int i;

		SCREEN_POSITION( laser, screen_x, screen_y );

		for ( i = 0; i < LASER_POINTS_NUM; i ++ ) {
			converted[i].x = ( short )( screen_x + (
						    points[i][0] * cos( laser->prot ) -
						    points[i][1] * sin( laser->prot ) ) );

			converted[i].y = ( short )( screen_y - (
						    points[i][0] * sin( laser->prot ) +
						    points[i][1] * cos( laser->prot ) ) );

			if ( rlib_rect_within( &( laser->screen ), converted[i].x, converted[i].y ) ) {
				culling = 0;
			}
		}

		if ( culling ) {
			return;
		}

		rlib_gt_set_foreground_color( laser->gt_app, 0, RL_GT_MAX_RGB, RL_GT_MAX_RGB );
		rlib_gt_fill_polygon( laser->gt_app, converted, 
			   LASER_POINTS_NUM, RL_GT_POLYGON_CONVEX );
	}
}


/* End of laser.c */
