/*
 * Copyright (c) 2005,2006 Ryo Ichinose
 *
 * This file is part of Space Maze.
 * 
 * Space Maze is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; version 2 of the License.
 * 
 * Space Maze is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with Space Maze; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
 */

/*!
 * @file
 * @brief Handles missile (mine) data and draws it onto the screen.
 *
 * "$Id: mine.c,v 1.1.1.1 2006/07/22 18:07:56 ryo Exp $"
 */

#include <math.h>
#include <stdio.h>

#include "RLgt.h"
#include "RLrect.h"
#include "missile.h"
#include "entity.h"


#define MINE_WIDTH    5
#define MINE_HEIGHT   5
#define MINE_STRENGTH 5 
#define MINE_VELOCITY 1.7


/*!
 * Initializes a missile (mine) specific data.
 * No null check is executed because this is a back-end of missile_init().
 */
void
mine_init( Entity* mine )
{
	mine->width         = MINE_WIDTH;
	mine->height        = MINE_HEIGHT;
	mine->strength      = MINE_STRENGTH;
	mine->vmax          = ( MINE_VELOCITY / entity_get_fps_ratio() );
	mine->draw_func     = mine_draw;
}


/*!
 * Draws a missile (mine) onto the screen.
 * No null check is executed because this is a back-end of entity_draw().
 */
void
mine_draw( Entity* mine )
{
	if ( entity_is_alive( mine ) ) {
		int screen_x;
		int screen_y;

		SCREEN_POSITION( mine, screen_x, screen_y );

		if ( ! rlib_rect_within( &( mine->screen ), screen_x, screen_y ) ) {
			return;
		}
			     
		rlib_gt_set_foreground_color( mine->gt_app, RL_GT_MAX_RGB, RL_GT_MAX_RGB, 0 );
		rlib_gt_fill_arc(
			mine->gt_app,
			screen_x - mine->width  / 2,
			screen_y - mine->height / 2,
			mine->width,
			mine->height,
			0,
			360 * 64
			);
	}
}


/* End of mine.c */
