/*
 * Copyright (c) 2005,2006 Ryo Ichinose
 *
 * This file is part of Space Maze.
 * 
 * Space Maze is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; version 2 of the License.
 * 
 * Space Maze is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with Space Maze; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
 */

/*!
 * @file
 * @brief Handles missile (ripple) data and draws it onto the screen.
 *
 * "$Id: ripple.c,v 1.1.1.1 2006/07/22 18:07:56 ryo Exp $"
 */

#include <math.h>
#include <stdio.h>

#include "RLgt.h"
#include "RLrect.h"
#include "missile.h"
#include "entity.h"


#define RIPPLE_WIDTH    10
#define RIPPLE_HEIGHT   10
#define RIPPLE_STRENGTH 10
#define RIPPLE_VELOCITY 3.0


/*!
 * Initializes a missile (ripple) specific data.
 * No null check is executed because this is a back-end of missile_init().
 */
void
ripple_init( Entity* ripple )
{
	ripple->width        = RIPPLE_WIDTH;
	ripple->height       = RIPPLE_HEIGHT;
	ripple->strength     = RIPPLE_STRENGTH;
	ripple->vmax         = ( RIPPLE_VELOCITY / entity_get_fps_ratio() );
	ripple->draw_func    = ripple_draw;
}


/*!
 * Draws a missile (ripple) onto the game screen.
 * No null check is executed because this is a back-end of entity_draw().
 */
void
ripple_draw( Entity* ripple )
{
#define RIPPLE_POINTS_NUM 5

	if ( ripple->is_alive ) {
		const double points[ RIPPLE_POINTS_NUM ][2] = {
			{   2.5,   5.0 },
			{   2.5, - 5.0 },
			{ - 2.5, -15.0 },
			{ - 2.5,  15.0 },
			{   2.5,   5.0 }
		};

		Point converted[ RIPPLE_POINTS_NUM ];
		int screen_x;
		int screen_y;
		int culling = 1;
		int i;

		SCREEN_POSITION( ripple, screen_x, screen_y );

		for ( i = 0; i < RIPPLE_POINTS_NUM; i ++ ) {
			converted[i].x = ( short )( screen_x + (
						    points[i][0] * cos( ripple->prot ) -
						    points[i][1] * sin( ripple->prot ) ) );

			converted[i].y = ( short )( screen_y - (
						    points[i][0] * sin( ripple->prot ) +
						    points[i][1] * cos( ripple->prot ) ) );

			if ( rlib_rect_within( &( ripple->screen ), converted[i].x, converted[i].y ) ) {
				culling = 0;
			}
		}

		if ( culling ) {
			return;
		}

		rlib_gt_set_foreground_color( ripple->gt_app, 0, RL_GT_MAX_RGB, 0 );
		rlib_gt_fill_polygon( ripple->gt_app, converted, 
			   RIPPLE_POINTS_NUM, RL_GT_POLYGON_CONVEX );
	}
}


/* End of ripple.c */
