/*
 * Copyright (c) 2005,2006 Ryo Ichinose
 *
 * This file is part of Space Maze.
 * 
 * Space Maze is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; version 2 of the License.
 * 
 * Space Maze is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with Space Maze; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
 */

/*!
 * @file
 * @brief Header file of the module that handles the information panel
 *        that will be located on the right side of the screen
 *        while you're in play.
 *
 * "$Id: playinfo.h,v 1.1.1.1 2006/07/22 18:07:56 ryo Exp $"
 */

#ifndef ___PLAYINFO_H_INCLUDED_
#define ___PLAYINFO_H_INCLUDED_

#ifdef HAVE_CONFIG_H
# include "config.h"
#endif

#ifdef HAVE_SYS_TIME_H
#  include <sys/time.h>
#endif

#include "RLgt.h"
#include "RLrect.h"


#define PLAYINFO_KEY_NUM 3


/*!
 * @brief Data structure to hold data of the information panel.
 */
typedef struct
{
#ifdef HAVE_SYS_TIME_H
	struct timeval previous_time;
	struct timeval elapsed_time;
#endif
	RLgtApp* gt_app;
	RLrect screen;
	
	int* image_index;
	int energy;
	int keys[ PLAYINFO_KEY_NUM ];
}
PlayInfo;


void playinfo_init( PlayInfo* playinfo, RLgtApp* app, RLrect* screen, int* image_index );
void playinfo_update( PlayInfo* playinfo );
void playinfo_draw( PlayInfo* playinfo );
void playinfo_reset_previous_time( PlayInfo* playinfo );
void playinfo_get_elapsed_time( PlayInfo* playinfo, int* min, int* sec );
int  playinfo_is_time_left( PlayInfo* playinfo );
void playinfo_get_radar_rect( PlayInfo* playinfo, RLrect* rect );
void playinfo_set_energy( PlayInfo* playinfo, int amount );
void playinfo_found_key( PlayInfo* playinfo, int number );
int  playinfo_is_key_found( PlayInfo* playinfo, int number );


#endif /* ___PLAYINFO_H_INCLUDED_ */

/* End of playinfo.h */
