/*
 * Copyright (c) 2005,2006 Ryo Ichinose
 *
 * This file is part of Space Maze.
 * 
 * Space Maze is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; version 2 of the License.
 * 
 * Space Maze is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with Space Maze; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
 */

/*!
 * @file
 * @brief Handles an star entity data and draws it onto the screen.
 *
 * "$Id: star.c,v 1.1.1.1 2006/07/22 18:07:56 ryo Exp $"
 */

#include <math.h>
#include <stdio.h>
#include <stdlib.h>
#include <string.h>

#include "RLgt.h"
#include "entity.h"
#include "star.h"


#define STAR_MAX_VELOCITY 0


/*!
 * Initializes star entity's data structure.
 * @param star [i/o] A star data storage.
 * @param app  [in]  GUI toolkit context.
 */
void
star_init( Entity* star, RLgtApp* app )
{
	RLrect screen;
	int width;
	int height;
	int sign;

	if ( star == NULL || app == NULL ) {
		return;
	}

	width  = rlib_gt_get_width( app );
	height = rlib_gt_get_height( app );

	screen.lefttop_x = 0;
	screen.lefttop_y = 0;
	screen.width     = width;
	screen.height    = height;
	
	entity_init( star, app, NULL, &screen );

	star->update_func = star_update;
	star->draw_func   = star_draw;

	star->px = RANDOM( ( double )width  );
	star->py = RANDOM( ( double )height );

	star->initial_px = star->px;
	star->initial_py = star->py;

	sign = ( int )pow( -1.0, 1.0 + ( int )RANDOM( 2.0 ) );
	star->vx = sign * ( int )RANDOM( STAR_MAX_VELOCITY );

	sign = ( int )pow( -1.0, 1.0 + ( int )RANDOM( 2.0 ) );
	star->vy = sign * ( int )RANDOM( STAR_MAX_VELOCITY );
}


/*!
 * Commit new position, status, etc. at the next frame.
 */
void
star_update( Entity* star, Entity* dummy )
{
	if ( star == NULL || star->gt_app == NULL ) {
		return;
	}

	star->px += star->vx;
	star->py += star->vy;

	if ( star->px < 0 || star->px >= star->screen.width  ) {
		star->px = star->initial_px;
	}

	if ( star->py < 0 || star->py >= star->screen.height ) {
		star->py = star->initial_py;
	}
}


/*!
 * Draws a star entity onto the screen.
 */
void
star_draw( Entity* star )
{
	int r;
	int g;
	int b;

	if ( star == NULL || star->gt_app == NULL ) {
		return;
	}

	r = ( int )( RL_GT_MAX_RGB * RANDOM( 1.0 ) );
	g = ( int )( RL_GT_MAX_RGB * RANDOM( 1.0 ) );
	b = ( int )( RL_GT_MAX_RGB * RANDOM( 1.0 ) );

	rlib_gt_set_foreground_color( star->gt_app, r, g, b );
	rlib_gt_draw_point( star->gt_app, star->px, star->py );
}


/* End of star.c */
