/*
 * Copyright (c) 2005,2006 Ryo Ichinose
 *
 * This file is part of Space Maze.
 * 
 * Space Maze is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; version 2 of the License.
 * 
 * Space Maze is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with Space Maze; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
 */

/*!
 * @file
 * Header file of modules which update information and 
 * draw screen according to the current game status.
 *
 * "$Id: state.h,v 1.1.1.1 2006/07/22 18:07:56 ryo Exp $"
 */

#ifndef ___STATE_H_INCLUDED_
#define ___STATE_H_INCLUDED_


#include "spacemaze.h"


#define STATE_DECREASE_ENERGY_AMOUNT 2


void   state_set_fps_ratio( double ratio );
double state_get_fps_ratio();
int    state_get_framecount_decrease_energy();
int    state_get_framecount_effect_blink();
int    state_get_framecount_effect_message();

void   state_title_init( SpaceMazeApp* app );
void   state_title_set_event_handler( SpaceMazeApp* app );
int    state_title_update( SpaceMazeApp* app );
void   state_title_draw( SpaceMazeApp* app );

void   state_select_init( SpaceMazeApp* app );
void   state_select_set_event_handler( SpaceMazeApp* app );
int    state_select_update( SpaceMazeApp* app );
void   state_select_draw( SpaceMazeApp* app );

void   state_boss_init( SpaceMazeApp* app, int level );
void   state_boss_set_event_handler( SpaceMazeApp* app );
int    state_boss_update( SpaceMazeApp* app );
void   state_boss_draw( SpaceMazeApp* app );

void   state_playing_init( SpaceMazeApp* app, int level );
void   state_playing_set_event_handler( SpaceMazeApp* app );
int    state_playing_update( SpaceMazeApp* app );
void   state_playing_draw( SpaceMazeApp* app );

void   state_pause_set_event_handler( SpaceMazeApp* app );
int    state_pause_update( SpaceMazeApp* app );
void   state_pause_draw( SpaceMazeApp* app );

void   state_gameover_set_event_handler( SpaceMazeApp* app );
int    state_gameover_update( SpaceMazeApp* app );
void   state_gameover_draw( SpaceMazeApp* app );

void   state_clear_init( SpaceMazeApp* app );
void   state_clear_set_event_handler( SpaceMazeApp* app );
int    state_clear_update( SpaceMazeApp* app );
void   state_clear_draw( SpaceMazeApp* app );

void   state_ending_set_event_handler( SpaceMazeApp* app );
void   state_ending_init( SpaceMazeApp* app );
int    state_ending_update( SpaceMazeApp* app );
void   state_ending_draw( SpaceMazeApp* app );

void   state_update_enemies( SpaceMazeApp* app, RLrect* s_rect_ptr );
void   state_update_enemy_missiles( SpaceMazeApp* app, RLrect* s_rect_ptr );
void   state_update_ship_missiles( SpaceMazeApp* app );
void   state_update_items( SpaceMazeApp* app, RLrect* s_rect_ptr );

void   state_draw_items( SpaceMazeApp* app );
void   state_draw_enemies( SpaceMazeApp* app );
void   state_draw_enemy_missiles( SpaceMazeApp* app );
void   state_draw_spaceship_missiles( SpaceMazeApp* app );
void   state_draw_enemy_info( SpaceMazeApp* app );

int    state_save( SpaceMazeApp* app );
int    state_load( SpaceMazeApp* app );


#define DRAW_IMAGE( app, index, cx, cy ) { \
        int width;  \
        int height; \
        int lt_x;   \
        int lt_y;   \
        RL_GT_LEFTTOP( (index), &( (app)->gt ), (cx), (cy), lt_x, lt_y, width, height ); \
        rlib_gt_draw_image( &( (app)->gt ), (index), 0, 0, width, height, lt_x, lt_y ); \
}


#endif /* ___STATE_H_INCLUDED_ */

/* End of state.h */
