/*
 * Copyright (c) 2003-2006 Ryo Ichinose
 *
 * This file is part of Space Maze.
 * 
 * Space Maze is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; version 2 of the License.
 * 
 * Space Maze is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with Space Maze; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
 */

/*!
 * @file
 * @brief Header file of list functions.
 *
 * $Id: RLlist.h,v 1.1.1.1 2006/07/22 18:07:56 ryo Exp $
 */

#ifndef ___RLLIST_H_INCLUDED_
#define ___RLLIST_H_INCLUDED_


/*********************************************************
 * RLLIST_MAX_DATA_LEN must be over the size of Entity 
 * defined in ../object/entity.h 
 *********************************************************/

#define RLLIST_MAX_DATA_LEN  512 /*!< Maximum length of each data in a list. */
#define RLLIST_MAX_DATA_NUM  128 /*!< Maximum data number that a list can hold. */


/*!
 * @brief Data element of a list.
 */
typedef struct _RLlistData {
	int index;
	int len;
	unsigned char buf[ RLLIST_MAX_DATA_LEN ];
	struct _RLlistData* next_ptr;
}
RLlistData;


/*!
 * @brief List.
 */
typedef struct {
	int         data_num;                     /*!< Num of registered data. */
	RLlistData  data[ RLLIST_MAX_DATA_NUM ];  /*!< Data storage area */
	RLlistData  start;                        /*!< Start node of the list */
	RLlistData  empty;                        /*!< Start node of the empty node list */
}
RLlist;


void rlib_list_init( RLlist* list_ptr );
int  rlib_list_is_full( const RLlist* list_ptr );
int  rlib_list_is_empty( const RLlist* list_ptr );

int rlib_list_contains( 
	RLlist* list_ptr, unsigned char* target, 
	int ( *func )( unsigned char* obj1, unsigned char* obj2 ) );

int rlib_list_size( const RLlist* list_ptr );
RLlistData* rlib_list_get( RLlist* list_ptr, int index );
int rlib_list_insert( RLlist* list_ptr, int index, unsigned char* buf, int len );

int rlib_list_insert_by_func( 
	RLlist* list_ptr, unsigned char* buf, int len,
	int ( *func )( unsigned char* new, unsigned char* old ) );

int  rlib_list_remove( RLlist* list_ptr, int index );
void rlib_list_clear( RLlist* list_ptr );
void rlib_list_print( const RLlist* list_ptr );


#endif /* ___RLLIST_H_INCLUDED_ */

/* End of RLlist.h */
