/*
 * Copyright (c) 2005,2006 Ryo Ichinose
 *
 * This file is part of Space Maze.
 * 
 * Space Maze is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; version 2 of the License.
 * 
 * Space Maze is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with Space Maze; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
 */

/*!
 * @file
 * @brief Sample application which explains how to use RLx code.
 */

#include <stdio.h>
#include <stdlib.h>
#include <string.h>
#include <X11/Xlib.h>
#include <X11/keysym.h>
#include "RLx.h"


static void check( RLXApp* app );
static void draw( RLXApp* app );
static void cleanup( void* data );


int 
main( int argc, char** argv )
{
	RLXApp app;
	int exitcode;

	if ( argc != 2 ) {
		fprintf( stderr, "Specify image file path.\n" );
		exit(1);
	}

	rlib_x_initialize( &app, "Sample application using RLxtools", -1, -1, -1, -1 );
	rlib_x_debug_on( &app );
	rlib_x_enable_dropframe( &app );
	rlib_x_load_image( &app, argv[1], RL_X_USE_MASK );
	rlib_x_set_update_func( &app, check );
	rlib_x_set_draw_func( &app, draw );
	rlib_x_set_cleanup_func( &app, cleanup, &app );
	rlib_x_start( &app );
	rlib_x_get_exitcode( &app, &exitcode );

	return exitcode;
}


static int is_space;
static int is_button1;


static void
check( RLXApp* app )
{
	if ( rlib_x_key_pressed( app, XK_Escape ) ) {
		rlib_x_stop( app, -2 );
	}

	if ( rlib_x_key_pressed( app, XK_space ) ) {
		is_space = 1;
	}

	if ( rlib_x_key_released( app, XK_space ) ) {
		is_space = 0;
	}

	if ( rlib_x_mouse_pressed( app, Button1, NULL, NULL ) ) {
		is_button1 = 1;
	}

	if ( rlib_x_mouse_released( app, Button1, NULL, NULL ) ) {
		is_button1 = 0;
	}
}


static void
draw( RLXApp* app )
{
	Drawable d;
	XColor color;
	XColor exact;
	unsigned long green;
	char string[32];

	XAllocNamedColor( app->display, app->cmap, "green", &color, &exact );
	green = color.pixel;

	rlib_x_get_drawable( app, &d );

	XSetForeground( app->display, app->gc, green );
	XFillRectangle( app->display, d, app->gc, 0, 0, app->width, app->height );
	rlib_x_draw_pixmap( app, 0, 0, 0, -1, -1, 0, 200 );
	XSetForeground( app->display, app->gc, app->black );

	if ( is_space ) {
		strcpy( string, "SPACE KEY IS PRESSED" );
		XDrawString( app->display, d, app->gc, 10, 10, string, strlen( string ) );
	}

	if ( is_button1 ) {
		strcpy( string, "BUTTON1 IS PRESSED" );
		XDrawString( app->display, d, app->gc, 10, 50, string, strlen( string ) );
	}
}


static void
cleanup( void* data )
{
	printf( "This is the user specified cleanup function.\n" );
}


/* End of xsample.c */
